function L=wheeler(n,ri,ro,b)

	% n  = number of turns in coil
	% ri = inner radius of coil in inches
	% ro = outer radius of coil in inches
	% b  = axial length of coil in inches

a=(ri+ro)/2;
c=abs(ro-ri);

L= (8e-7 * n^2 * a^2)/(6*a + 9*b + 10*c); 
